---
name: Question
about: Do you have a question ?
title: "[Q]"
labels: documentation, question
assignees: Mara-Li

---

*Describe your question here*

**Platform (please complete the following information):**
- OS: [e.g. iOS]
- Obsidian Ver.:
